# flounder
flounder is a library that create Entity of Dialogflow.
This library uses RestAPI of dialogflow. It is not an official library.

## Installation

```
pip install flounder
```

## Example

```
foo
```

## License
flounder is licensed under MIT License. See LICENSE for more information.